package xframework.com.controller;

import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import xdataset5.XDataSet5;
import xdataset5util.XDataSet5Conv;
import xframework.com.service.ExampleService;

@Controller
public class CustomXDataSet5Contoller {
	
	@Resource(name = "exampleService")
	private ExampleService exampleService;
	private Log log = LogFactory.getLog(this.getClass());
	private static final String XFRAME5_SELECT = "SELECT";
	private static final String XFRAME5_UPDATE = "UPDATE";
	
	/**
	 * xframe5 조회  (공통 서비스 처리) 샘플 
	 * @param request HttpServletRequest
	 * @param response HttpServletResponse
	 * @param model ModelMap
	 */
	@RequestMapping(value = "/sample/customService.do")
	public void customService(HttpServletRequest request, HttpServletResponse response, ModelMap model) {
		log.info("xframe5 조회  (공통 서비스 처리)");
		
		XDataSet5 xDataSet5 		= null;
		Map<String, Object> element = null;
		int nRow 					= 0;
		
		try {
			
			// XDataSet5오브젝트 생성
			xDataSet5 = new XDataSet5(request, response);
			
			// 파라미터 데이터 설정
			String _SID = request.getParameter("SID");
			String _SQLID = request.getParameter("SQLID");
			String _IN_DATASET = request.getParameter("IN_DATASET");
			String _OUT_DATASET = request.getParameter("OUT_DATASET");
			
			Map<String, Object> xDataSet5Map = XDataSet5Conv.convXDataSetToXDataSetMap(xDataSet5);
			List<Map<String, Object>> inputList = (List<Map<String, Object>>) xDataSet5Map.get(_IN_DATASET);
			
			if (_SQLID == null || _SQLID.length() == 0) {
				xDataSet5.setErrorMessage("-2", "[서비스 오류] SQLID 정보를 확인하세요. SQLID > " + _SQLID);
				xDataSet5.returnData();
				return;
			}
			
			if (inputList == null) {
				xDataSet5.setErrorMessage("-3", "[서비스 오류] IN_DATASET 정보를 확인하세요. IN_DATASET > " + _IN_DATASET);
				xDataSet5.returnData();
				return;
			}
			
			if (_OUT_DATASET == null || _OUT_DATASET.length() == 0) {
				xDataSet5.setErrorMessage("-4", "[서비스 오류] OUT_DATASET 정보를 확인하세요. OUT_DATASET > " + _OUT_DATASET);
				xDataSet5.returnData();
				return;
			}
			
			// IN_DATASET 의 첫번째 데이터맵
			Map<String, Object> inputMap = inputList.get(0);
			
			// SQL ID 설정
			inputMap.put("_SQLID", _SQLID);
			
			if (_SID.equals(XFRAME5_SELECT)) {
				List<Map<String,Object>> resultList = exampleService.selectCustomService(inputMap);
				Iterator<Map<String, Object>> iterator = resultList.iterator();
				while (iterator.hasNext()) {
					element = iterator.next();
					for ( String key : element.keySet() ) {
					    xDataSet5.setData(_OUT_DATASET, key, nRow, String.valueOf(element.get(key)));
					}
				    nRow++;
				}
				
				// xDataSet5.setUserHeader("user_header_msg");  // 유저헤더메세지 설정 
				xDataSet5.setMessage("100", "조회가 완료 되었습니다."); // 결과 메세지 설정
				
				xDataSet5.returnData();	// response로 데이터 반환처리함
				
			} else if (_SID.equals(XFRAME5_UPDATE)) {
				// TODO : 업데이트 처리
				
			} else {
				xDataSet5.setErrorMessage("-1", "[서비스 오류] SID를 확인하세요. SID > " + _SID);
				xDataSet5.returnData();
				return;
			}
			
			
		} catch (Exception e) {	
			e.printStackTrace();
			log.error("customService = " + e);
			try {
				if(xDataSet5 != null) {
					// 로직 처리중 Exception이 발생할 경우, XDataSet5오브젝트에 에러 코드와 에러 메시지를 설정하고 송신
					xDataSet5.setErrorMessage("-100", e.toString());
					xDataSet5.returnData();	//response로 데이터 반환처리	
				}
			} catch (Exception ex) {
				log.error(ex);
			}
		}
	}
}
