﻿/*
 * 공통 모듈 : SYSCOM
 * 공통영역 개발 
 * 최초작성일자  2020-06-17
 * 최초작성자	윤상준
 * 버전 	   
 --------------------------------
*/


//////// 시스템에서 사용하는 전역변수 영역 ////////

// 거래시 전송할 USER HEADER 
var LOGIN_USER_ID = "User001";
var LOGIN_USER_NAME = "TestUser01";


// 프레임을 구성하는 화면 및 멤버에 대한 변수 정의
var WIN_MAIN_SCREEN, WIN_MAIN_MEMBER;
var WIN_MAIN_MIDDLE_TAB;
var TOP_MAIN_SCREEN, TOP_MAIN_MEMBER;
var VACANCY_SCREEN, VACANCY_MEMBER;
var BOTTOM_MAIN_SCREEN, BOTTOM_MAIN_MEMBER;
var MIDDLE_MAIN_SCREEN, MIDDLE_MAIN_MEMBER;
var LEFT_MAIN_SCREEN, LEFT_MAIN_MEMBER;
var RIGHT_MAIN_SCREEN, RIGHT_MAIN_MEMBER;
var EVENT_MAIN_SCREEN, EVENT_MAIN_MEMBER;
var LIB_MAIN_SCREEN, LIB_MAIN_MEMBER;

// Middle Main의 좌측, 우측, 중앙 탭
var MIDDLE_MAIN_LEFT_TAB, MIDDLE_MAIN_RIGHT_TAB, MIDDLE_MAIN_MIDDLE_TAB;



//////// 시스템에서 사용하는 공통함수 영역 ////////


/**
 * 비동기 Transaction 데이터 송신
 * @param objBizScreen 이 함수를 호출한 업무 화면 오브젝트
 * @param strTranMapId 트랜 맵 아이디
 * @param 
 * @return 
 * 	true 성공
 *	 false 실패
 */
function requestSubmitAsync(objBizScreen, strTranMapId, userHeader) 
{		

	// 화면 오브젝트 인스턴스 파라미터 검증
	if(factory.isobject(objBizScreen) == false) {
		objBizScreen.alert("화면 오브젝트 파라미터가 오브젝트가 아닙니다.");
		return false;
	}
	// 업무 화면의 멤버를 구함
	var objBizScreenMember = objBizScreen.getmembers(XFD_JAVASCRIPT);
	if(factory.isobject(objBizScreenMember) === false) {
		objBizScreen.alert("업무 화면의 멤버를 찾을 수 없습니다.");
		return false;
	}
	factory.consoleprint("멤버 완료");

	
	factory.consoleprint("헤더 설정 ");
	// 사용자 헤더 설정
	setUserHeader(objBizScreen, strTranMapId, userHeader);

		
	// 거래 송신
	factory.consoleprint("거래시작");
	
	if(objBizScreen.requestsubmit(strTranMapId, true) == false) {
		objBizScreen.alert("데이터 송신중 오류가 발생하였습니다.");
		return false;
	}
	return true;
}


/**
 * 업무 서버로 데이터를 송신하기 전에 사용자 헤더를 설정합니다.
 * @param objBizScreen 업무 화면 오브젝트
 * @param strTranMapId 트랜잭션 맵 ID
 * @param strUserHeader 사용자 헤더 스트링
 * @return
 * 	true 성공
 * 	false 실패
 */
function setUserHeader(objBizScreen, strTranMapId, strUserHeader)
{
	var sttHeader = "";
	
	// 기본 헤더 설정
	sttHeader += "LOGIN_USER_ID=" + this.LOGIN_USER_ID;
	sttHeader += "&LOGIN_USER_NAME=" + this.LOGIN_USER_NAME;
	
	
	// 사용자 헤더 부분 설정
	if(strUserHeader != null && strUserHeader != undefined) {
		sttHeader += "&USER_HEADER=" + strUserHeader;
	}

	objBizScreen.setuserheader(sttHeader);

}



/**
 * 새로운 업무 화면을 오픈한다.
 * @param strScreenUrl 화면 전체 경로 (예: "/SYS/MIDDLE/MiddleMain")
 * @return
 * 	true 성공
 * 	false 실패
 */ 
function loadScreen(strScreenUrl, naviArr)
{
	var strScreenUrlLength = strScreenUrl.length;
	
	factory.consoleprint("loadScreen " + strScreenUrl);
	// 인트로 탭을 숨김
	if(this.WIN_MAIN_MIDDLE_TAB.gettabitemfocus() != 0) {
		this.WIN_MAIN_MIDDLE_TAB.settabitemfocus(0);
	}
				
	var nLength = strScreenUrl.length;
	
	if(strScreenUrlLength > 0) {
		
		// FrameScreen 화면에 전달할 업무 화면에 대한 정보 어레이
		var arrScreenInfo = [];

		// 화면 Full URL 정보 설정
		arrScreenInfo["SCREEN_URL"] = strScreenUrl;
		
		var arrInfo = [];
		arrInfo.push(arrScreenInfo);
		arrInfo.push(naviArr);
		this.loadFrameScreen(arrInfo);
	}
}

/**
 * 메인영역에 화면을 열 경우 비동기 처리를 위해 사용되는 함수.
 * @param arrBizScreenInfo 화면호출시 필요한 정보를 가지고 있는 어레이
 * @return
 */ 
function loadFrameScreen(objBizScreenInfo)
{
	// MDI 방식에서 싱글방식으로 변경 : 속도 개선
	if(this.MIDDLE_MAIN_MIDDLE_TAB.gettabitemcount() == 0){
		this.MIDDLE_MAIN_MIDDLE_TAB.addtab("", 0, this.SCREEN_TAB_ITEM_WIDTH, "/SYS/FRAME/ScreenFrame", true, objBizScreenInfo);
	}else{
		this.MIDDLE_MAIN_MIDDLE_TAB.setinnerscreenurl(0, "/SYS/FRAME/ScreenFrame", objBizScreenInfo);
	}
	
	//return;
}


/**
 * 새로운 팝업 화면을 오픈한다.
 * @param objBizScreen 팝업 화면을 열고자 하는 업무 화면 오브젝트
 * @param strScreenUrl 화면 전체 경로 (예: "/CCN/MIDDLE/MiddleMain")
 * @return
 * 	true 성공
 * 	false 실패
 */ 
function loadPopup(objBizScreen, strScreenUrl)
{
	if(factory.isobject(objBizScreen) == false) {
		return false;
	}
	
	if(strScreenUrl == undefined) {
		return false;
	}
	
	if(strScreenUrl.length == 0) {
		return false;
	}
		
	// FramePopup 화면에 전달할 업무 화면에 대한 정보 어레이
	var arrScreenInfo = [];

	// 화면 Full URL 정보 설정
	arrScreenInfo["SCREEN_URL"] = strScreenUrl;
	arrScreenInfo["PARENT_BIZ_SCREEN"] = objBizScreen;	
		

	var nWindowId = objBizScreen.getwindowid();
	var strPopupName = nWindowId.toString(10);
	factory.loadpopup(strPopupName, "/SYS/FRAME/PopupFrame", "", true, XFD_BORDER_RESIZE, 0, 0, true, true, objBizScreen, arrScreenInfo);	
	//factory.loadpopupex(strPopupName, "/SYS/FRAME/PopupFrame", "", true, XFD_BORDER_RESIZE, 0, 0, 0, 0, true, true, true, objBizScreen, arrScreenInfo);	
	
	return true;
}


/**
 * 공통코드 서비스를 호출한다..
 * @param objBizScreen 화면 오브젝트
 * @param strCodekey 공통코드 조회 코드키
 * @param objDataset 공통코드 데이터셋
 * @return
 * 	
 * 	
 */ 
function requestCodeDataset(objBizScreen, strCodekey, objDataset)
{
	
	
	
	
}

/**
 * 공통코드 서비스를 호출한다..
 * @param objBizScreen 화면 오브젝트
 * @param strCodekey 공통코드 조회 코드키
 * @param objCombobox 콤보박스 오브젝트
 * @return
 * 	
 * 	
 */ 
function requestCodeData(objBizScreen, strCodekey, objCombobox)
{
	// 화면 오브젝트 인스턴스 파라미터 검증
	if(factory.isobject(objBizScreen) == false) {
		objBizScreen.alert("화면 오브젝트 파라미터가 오브젝트가 아닙니다.");
		return;
	}
	// 업무 화면의 멤버를 구함
	var objBizScreenMember = objBizScreen.getmembers(XFD_JAVASCRIPT);
	if(factory.isobject(objBizScreenMember) === false) {
		objBizScreen.alert("업무 화면의 멤버를 찾을 수 없습니다.");
		return;
	}
	
	// 콤보박스 인스턴스 파라미터 검증
	if(factory.isobject(objCombobox) == false) {
		objBizScreen.alert("콤보박스 오브젝트 파라미터가 오브젝트가 아닙니다.");
		return;
	}

	
	if(strCodekey.length < 1){
		objBizScreen.alert("조회할 공통코드가 올바르지 않습니다. CODE_KEY : "+ strCodekey);
		return;
	}
	
	
	// 공통코드 서비스 호출 
	// XFD_XDATASET_TRAN_CLEAR 가 없음...........
	// 데이터셋 두개로 처리
	var strTranMapID = "TR_COM_CODE";
	var strGdsI = "gds_com_codeI";
	var strGdsO = "gds_com_codeO";
	var instGXDataSetI = factory.getglobalxdataset(strGdsI);
	var instGXDataSetO = factory.getglobalxdataset(strGdsO);
	
	// 데이터셋 초기화
	instGXDataSetI.init();
	instGXDataSetO.init();
	// 검색코드 설정
	instGXDataSetI.insertrow(0);
	instGXDataSetI.setdatabyname(0 , "COM_CODE_ID", strCodekey);
	
	// 트랜맵설정
	objBizScreen.addxtranmap(strTranMapID, "common/getCodeList.do", "");
	objBizScreen.addgxdatasetinxtranmap(strGdsI);
	objBizScreen.addgxdatasetinxtranmap(strGdsO);
	objBizScreen.setxtranmapiotype(strTranMapID, strGdsI, XFD_XDATASET_TRAN_ALL, XFD_XDATASET_TRAN_NONE);
	objBizScreen.setxtranmapiotype(strTranMapID, strGdsO, XFD_XDATASET_TRAN_NONE, XFD_XDATASET_TRAN_APPEND);
	objBizScreen.setxtranmapiocolumn(strTranMapID, strGdsI, "COM_CODE_ID", true, false);
	objBizScreen.setxtranmapiocolumn(strTranMapID, strGdsO, "COM_CODE_ID", false, true);
	objBizScreen.setxtranmapiocolumn(strTranMapID, strGdsO, "COM_CODE", false, true);
	objBizScreen.setxtranmapiocolumn(strTranMapID, strGdsO, "COM_CODE_NM", false, true);

	// 거래 송신
	factory.consoleprint("거래시작");
	if(objBizScreen.requestsubmit(strTranMapID, false) == false) {
		objBizScreen.alert("공통코드 처리중 오류가 발생하였습니다.");
		return;
	}
	
	var instResult = objBizScreen.getsubmitresult();
    if(instResult == null) {
        objBizScreen.alert("공통코드 데이터 처리 결과를 얻을 수 없습니다.");
        return;
    }else{
		// 콤보 오브젝트 초기화(리스트 전체삭제)
		objCombobox.removeall();  
		factory.consoleprint("gds rowconut : "+ instGXDataSetO.getrowcount());
		if(instGXDataSetO.getrowcount() > 0){
			for(var i=0; i< instGXDataSetO.getrowcount(); i++){
				factory.consoleprint("gds code : "+ instGXDataSetO.getdatabyname(i,"COM_CODE"));
				factory.consoleprint("gds code_nm : "+ instGXDataSetO.getdatabyname(i,"COM_CODE_NM"));
				// 콤보 데이터 설정
				objCombobox.addstring(instGXDataSetO.getdatabyname(i,"COM_CODE") + ":" + instGXDataSetO.getdatabyname(i,"COM_CODE_NM"));
			}
		}
	}

	
	// 임시 
	//objCombobox.removeall();  // 콤보리스트 전체삭제
	//objCombobox.addstring("1:한국");
	//objCombobox.addstring("2:호주");
	//objCombobox.addstring("3:독일");
	
	objCombobox.setselectedindex(0); // 0번째 값 선택
	
}


/**
 * 공통코드 서비스를 호출한다..
 * @param objBizScreen 화면 오브젝트
 * @param strCodekey 공통코드 조회 코드키
 * @param objGrid 그리드 오브젝트
 * @param nColIndex 컬럼 인덱스
 * @return
 * 	
 * 	
 */ 
function requestCodeDataGrid(objBizScreen, strCodekey, objGrid, nColIndex)
{
	// 화면 오브젝트 인스턴스 파라미터 검증
	if(factory.isobject(objBizScreen) == false) {
		objBizScreen.alert("화면 오브젝트 파라미터가 오브젝트가 아닙니다.");
		return;
	}
	// 업무 화면의 멤버를 구함
	var objBizScreenMember = objBizScreen.getmembers(XFD_JAVASCRIPT);
	if(factory.isobject(objBizScreenMember) === false) {
		objBizScreen.alert("업무 화면의 멤버를 찾을 수 없습니다.");
		return;
	}
	
	// 그리드 인스턴스 파라미터 검증
	if(factory.isobject(objGrid) == false) {
		objBizScreen.alert("그리드 오브젝트 파라미터가 오브젝트가 아닙니다.");
		return;
	}

	
	if(strCodekey.length < 1){
		objBizScreen.alert("조회할 공통코드가 올바르지 않습니다. CODE_KEY : "+ strCodekey);
		return;
	}
	
	
	// 공통코드 서비스 호출 
	// XFD_XDATASET_TRAN_CLEAR 가 없음...........
	// 데이터셋 두개로 처리
	var strTranMapID = "TR_COM_CODE";
	var strGdsI = "gds_com_codeI";
	var strGdsO = "gds_com_codeO";
	var instGXDataSetI = factory.getglobalxdataset(strGdsI);
	var instGXDataSetO = factory.getglobalxdataset(strGdsO);
	
	// 데이터셋 초기화
	instGXDataSetI.init();
	instGXDataSetO.init();
	// 검색코드 설정
	instGXDataSetI.insertrow(0);
	instGXDataSetI.setdatabyname(0 , "COM_CODE_ID", strCodekey);
	
	// 트랜맵설정
	objBizScreen.addxtranmap(strTranMapID, "common/getCodeList.do", "");
	objBizScreen.addgxdatasetinxtranmap(strGdsI);
	objBizScreen.addgxdatasetinxtranmap(strGdsO);
	objBizScreen.setxtranmapiotype(strTranMapID, strGdsI, XFD_XDATASET_TRAN_ALL, XFD_XDATASET_TRAN_NONE);
	objBizScreen.setxtranmapiotype(strTranMapID, strGdsO, XFD_XDATASET_TRAN_NONE, XFD_XDATASET_TRAN_APPEND);
	objBizScreen.setxtranmapiocolumn(strTranMapID, strGdsI, "COM_CODE_ID", true, false);
	objBizScreen.setxtranmapiocolumn(strTranMapID, strGdsO, "COM_CODE_ID", false, true);
	objBizScreen.setxtranmapiocolumn(strTranMapID, strGdsO, "COM_CODE", false, true);
	objBizScreen.setxtranmapiocolumn(strTranMapID, strGdsO, "COM_CODE_NM", false, true);

	// 거래 송신
	factory.consoleprint("거래시작");
	if(objBizScreen.requestsubmit(strTranMapID, false) == false) {
		objBizScreen.alert("공통코드 처리중 오류가 발생하였습니다.");
		return;
	}
	
	var instResult = objBizScreen.getsubmitresult();
    if(instResult == null) {
        objBizScreen.alert("공통코드 데이터 처리 결과를 얻을 수 없습니다.");
        return;
    }else{
		// 콤보 오브젝트 초기화(리스트 전체삭제)
		objGrid.deleteallcombostringtocolumn(nColIndex);  
		factory.consoleprint("gds rowconut : "+ instGXDataSetO.getrowcount());
		if(instGXDataSetO.getrowcount() > 0){
			for(var i=0; i< instGXDataSetO.getrowcount(); i++){
				factory.consoleprint("gds code : "+ instGXDataSetO.getdatabyname(i,"COM_CODE"));
				factory.consoleprint("gds code_nm : "+ instGXDataSetO.getdatabyname(i,"COM_CODE_NM"));
				// 콤보 데이터 설정
				objGrid.addcombostringtocolumn(nColIndex, instGXDataSetO.getdatabyname(i,"COM_CODE") + ":" + instGXDataSetO.getdatabyname(i,"COM_CODE_NM"));
			}
		}
	}
	
}

/**
 * 메시지창 호출
 * @param scrParent Parent 화면
 * @param strMsg 다이얼로그 박스에 기본적으로 출력할 메시지
 * @param nMsgType : 1=정보(Infomation), 2=경고(Warning), 3=에러(Error), 4=확인(Question)
 * @param strName : 메시지 팝업 이름 (default : MESSAGE)
 * @param strTitle : 메시지 팝업 타이틀 (default : 메시지팝업)
 * @Return 확인, 닫기 -> XFD_MB_RESOK, 취소 -> XFD_MB_RESCANCEL, 아니오 -> XFD_MB_RESNO, 예 -> XFD_MB_RESYES
 */
function showMsg(scrParent, nMsgType, strName, strTitle, strMsg, bModal)
{
	if(strName == undefined || strName == null || strName.length == 0)
		strName = "MESSAGE";
	
	if(strTitle == undefined || strTitle == null || strTitle.length == 0)
		strTitle = "";
	
	if(scrParent == undefined || scrParent == null)
		scrParent = WIN_MAIN_SCREEN;
	
	if(bModal == undefined)
		bModal = true;

	var AScrInfo = {};
	AScrInfo["screen"] = scrParent;
	AScrInfo["m_nMsgType"] = nMsgType;
	AScrInfo["m_strTitle"] = strTitle;
	AScrInfo["m_strMsg"] = strMsg;

	factory.loadpopupex(strName, "/SYS/COMPONENT/MessageContent", "MESSAGE", true, XFD_BORDER_RAISED, 0, 0, 0, 0, true, true, bModal, scrParent, AScrInfo);

	return 1;
}


/**
 * 메시지창(포틀릿) 호출
 * @param scrParent Parent 화면
 * @param nMsgType : 1=정보(Infomation), 2=경고(Warning), 3=에러(Error), 4=확인(Question)
 * @param strName : 메시지 팝업 이름 (default : MESSAGE)
 * @param strTitle : 메시지 팝업 타이틀 (default : 메시지팝업)
 * @param strMsg : 다이얼로그 박스에 기본적으로 출력할 메시지
 * @Return 확인, 닫기 -> XFD_MB_RESOK, 취소 -> XFD_MB_RESCANCEL, 아니오 -> XFD_MB_RESNO, 예 -> XFD_MB_RESYES
 */
function showMsgPortlet(scrParent, nMsgType, strName, strTitle, strMsg)
{
	if(strName == undefined || strName == null || strName.length == 0)
		strName = "MESSAGE";
	
	if(strTitle == undefined || strTitle == null || strTitle.length == 0)
		strTitle = "메시지팝업";
	
	if(scrParent == undefined || scrParent == null)
		scrParent = WIN_MAIN_SCREEN;

	var AScrInfo = {};
	AScrInfo["screen"] = scrParent;
	AScrInfo["m_nMsgType"] = nMsgType;
	AScrInfo["m_strTitle"] = strTitle;
	AScrInfo["m_strMsg"] = strMsg;

	scrParent.loadportletpopup(strName, "/SYS/COMPONENT/MessagePortlet", strTitle, true, XFD_BORDER_RAISED, 0, 0, 0, 0, true, true, false, AScrInfo);

	return 1;
}
